Crate linera_service_graphql_client

Crate linera_service_graphql_client 

A GraphQL client for the node service.

Re-exports

pub use utils::*;

Modules

applications
block
blocks
chain
chains
notifications
transfer
utils

Structs

ApplicationDescription
Description of a user application.
Applications
Block
Blocks
Chain
ChainManager
The state of the certification process for a chain’s next block.
ChainOwnership
Represents the owner(s) of a chain.
Chains
Epoch
A number identifying the configuration of the chain (aka the committee).
IncomingBundle
A bundle of cross-chain messages.
MessageBundle
A set of messages from a single block, for a single destination.
Notification
Notification that a chain has a new certified block or a new message.
Notifications
OperationResult
The execution result of a single operation.
Transfer

Enums

ConversionError
Message
A message to be sent and possibly executed in the receiver’s block.
MessageAction
What to do with a message picked from the inbox.
MessageKind
The kind of outgoing message being sent.
Operation
An operation to be executed in a block.
Reason
Reason for the notification.
SystemOperation
A system operation.
Transaction
A transaction in a block: incoming messages or an operation.

Type Aliases

ApplicationId
JSONObject